==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/Analytics/AwsGlueDataCatalog.md <==
# AwsGlueDataCatalog


```text
aws-20210730/Resource/Analytics/AwsGlueDataCatalog
```

```text
include('aws-20210730/Resource/Analytics/AwsGlueDataCatalog')
```



| Illustration | AwsGlueDataCatalog | AwsGlueDataCatalogCard | AwsGlueDataCatalogGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Analytics/AwsGlueDataCatalog.png) | ![illustration for AwsGlueDataCatalog](../../../aws-20210730/Resource/Analytics/AwsGlueDataCatalog.Local.png) | ![illustration for AwsGlueDataCatalogCard](../../../aws-20210730/Resource/Analytics/AwsGlueDataCatalogCard.Local.png) | ![illustration for AwsGlueDataCatalogGroup](../../../aws-20210730/Resource/Analytics/AwsGlueDataCatalogGroup.Local.png) |




## AwsGlueDataCatalog

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsGlueDataCatalog
include('aws-20210730/Resource/Analytics/AwsGlueDataCatalog')

' renders the element
AwsGlueDataCatalog('AwsGlueDataCatalog', 'Aws Glue Data Catalog', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsGlueDataCatalog
include('aws-20210730/Resource/Analytics/AwsGlueDataCatalog')

' renders the element
AwsGlueDataCatalog('AwsGlueDataCatalog', 'Aws Glue Data Catalog', 'an optional tech label')
@enduml
```

## AwsGlueDataCatalogCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsGlueDataCatalogCard
include('aws-20210730/Resource/Analytics/AwsGlueDataCatalog')

' renders the element
AwsGlueDataCatalogCard('AwsGlueDataCatalogCard', 'Aws Glue Data Catalog Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsGlueDataCatalogCard
include('aws-20210730/Resource/Analytics/AwsGlueDataCatalog')

' renders the element
AwsGlueDataCatalogCard('AwsGlueDataCatalogCard', 'Aws Glue Data Catalog Card', 'an optional description')
@enduml
```

## AwsGlueDataCatalogGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsGlueDataCatalogGroup
include('aws-20210730/Resource/Analytics/AwsGlueDataCatalog')

' renders the element
AwsGlueDataCatalogGroup('AwsGlueDataCatalogGroup', 'Aws Glue Data Catalog Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsGlueDataCatalogGroup
include('aws-20210730/Resource/Analytics/AwsGlueDataCatalog')

' renders the element
AwsGlueDataCatalogGroup('AwsGlueDataCatalogGroup', 'Aws Glue Data Catalog Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/Analytics/AwsGlueDataCatalog.md <==
# AwsGlueDataCatalog


```text
aws-20210730/Resource/Analytics/AwsGlueDataCatalog
```

```text
include('aws-20210730/Resource/Analytics/AwsGlueDataCatalog')
```



| Illustration | AwsGlueDataCatalog | AwsGlueDataCatalogCard | AwsGlueDataCatalogGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Analytics/AwsGlueDataCatalog.png) | ![illustration for AwsGlueDataCatalog](../../../aws-20210730/Resource/Analytics/AwsGlueDataCatalog.Local.png) | ![illustration for AwsGlueDataCatalogCard](../../../aws-20210730/Resource/Analytics/AwsGlueDataCatalogCard.Local.png) | ![illustration for AwsGlueDataCatalogGroup](../../../aws-20210730/Resource/Analytics/AwsGlueDataCatalogGroup.Local.png) |




## AwsGlueDataCatalog

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsGlueDataCatalog
include('aws-20210730/Resource/Analytics/AwsGlueDataCatalog')

' renders the element
AwsGlueDataCatalog('AwsGlueDataCatalog', 'Aws Glue Data Catalog', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsGlueDataCatalog
include('aws-20210730/Resource/Analytics/AwsGlueDataCatalog')

' renders the element
AwsGlueDataCatalog('AwsGlueDataCatalog', 'Aws Glue Data Catalog', 'an optional tech label')
@enduml
```

## AwsGlueDataCatalogCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsGlueDataCatalogCard
include('aws-20210730/Resource/Analytics/AwsGlueDataCatalog')

' renders the element
AwsGlueDataCatalogCard('AwsGlueDataCatalogCard', 'Aws Glue Data Catalog Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsGlueDataCatalogCard
include('aws-20210730/Resource/Analytics/AwsGlueDataCatalog')

' renders the element
AwsGlueDataCatalogCard('AwsGlueDataCatalogCard', 'Aws Glue Data Catalog Card', 'an optional description')
@enduml
```

## AwsGlueDataCatalogGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsGlueDataCatalogGroup
include('aws-20210730/Resource/Analytics/AwsGlueDataCatalog')

' renders the element
AwsGlueDataCatalogGroup('AwsGlueDataCatalogGroup', 'Aws Glue Data Catalog Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsGlueDataCatalogGroup
include('aws-20210730/Resource/Analytics/AwsGlueDataCatalog')

' renders the element
AwsGlueDataCatalogGroup('AwsGlueDataCatalogGroup', 'Aws Glue Data Catalog Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
